{
  config,
  lib,
  pkgs,
  ...
}:
with lib; {
  imports = [
    ./gaming.nix
    ./creative.nix # TODO: more fine grained choices, not every setup needs fspy or rawtherapee
    ./syncthing.nix
    ./kdeconnect.nix
    ./themeing.nix
    ./cloud.nix
    ./networking.nix
    ./social.nix
    ./mail.nix
    ./fonts.nix
    ./firefox.nix
    ./x.nix
    ./obs.nix
  ];

  programs.seahorse.enable = true;
  security.pam.services.jade.enableGnomeKeyring = true;

  virtualisation.libvirtd.enable = true;

  services = {
    printing = {
      enable = true;
      drivers = [
        pkgs.gutenprint
        pkgs.gutenprintBin
        pkgs.hplip
        pkgs.brlaser
        pkgs.brgenml1lpr
        pkgs.brgenml1cupswrapper
        pkgs.ptouch-driver
      ];
    };
  };

  programs.xss-lock = {
    enable = true;
    lockerCommand = "${pkgs.i3lock}/bin/i3lock -c 1d2021";
  };

  services.illum.enable = true;
  services.avahi = {
    enable = true;
    nssmdns4 = true;
    openFirewall = true;
  };
  services.smartd = {
    enable = true;
    notifications.test = true;
  };

  home-manager.users.jade = {pkgs, ...}: {
    home.sessionVariables = {
      "S10E_JRNL_FILE_LOC" = "/home/jade/Docs/jrnl.md";
    };
    programs.ssh = {
      controlMaster = "yes";
    };
    home.packages = with pkgs; [
      just
      bacon

      magic-wormhole-rs

      yt-dlp

      imagemagick

      syncplay

      # filemanager
      xfce.thunar
      xfce.tumbler
      xfce.thunar-archive-plugin
      file-roller

      # media/file viewers
      vlc
      mpv
      evince
      nomacs
      jellyfin-media-player

      # from environment.systemPackages cleanup
      virt-manager
      ddccontrol-db
      ffmpeg_7-full

      # external
      libnotify
      rofimoji
      xorg.xinput
      arandr
      flameshot
      tesseract5
      imagemagick
      brightnessctl
      drawing
    ];
    xsession = {
      enable = true;
    };
  };
}
